Safety

Enum Safety 

pub enum Safety {
    Safe(Safe),
    Unsafe(Unsafe),
    Default,
}
Safe, unsafe or default.

Variants



Safe(Safe)

The item is qualified as safe.



Unsafe(Unsafe)

The item is qualified as unsafe.



Default

The item is not qualified either way.

Implementations

Source

impl Safety

pub fn parse_safe_or_unsafe(input: ParseStream<'_>) -> Result<Self>

Parses safe, unsafe, or default (neither).

This is appropriate for matching the syntax of extern blocks, in which functions are unsafe by default and require safe otherwise.

unsafe extern "C" {
    fn implicitly_unsafe();
    unsafe fn explicitly_unsafe();
    safe fn explicitly_safe();
}
pub fn parse_unsafe_only(input: ParseStream<'_>) -> Result<Self>

Parses unsafe or default (nothing).

This is appropriate for functions not within an extern block, which are safe by default and cannot be explicitly marked safe.

fn implicitly_safe() {}
unsafe fn explicitly_unsafe() {}

// safe fn explicitly_safe() {}
// ^^^^ ERROR: items outside of `unsafe extern { }` cannot be declared with `safe` safety qualifier