TraitItem

Enum TraitItem 

#[non_exhaustive]
pub enum TraitItem { Const(TraitItemConst), Fn(TraitItemFn), Type(TraitItemType), Macro(TraitItemMacro), Verbatim(TokenStream), }
An item declaration within the definition of a trait.

Syntax tree enum

This type is a syntax tree enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Const(TraitItemConst)

An associated constant within the definition of a trait.



Fn(TraitItemFn)

An associated function within the definition of a trait.



Type(TraitItemType)

An associated type within the definition of a trait.



Macro(TraitItemMacro)

A macro invocation within the definition of a trait.



Verbatim(TokenStream)

Tokens within the definition of a trait not interpreted by Syn.

Important: see Compatibility notes.