Type

Enum Type 

#[non_exhaustive]
pub enum Type {
Show 15 variants Array(TypeArray), FnPtr(TypeFnPtr), Group(TypeGroup), ImplTrait(TypeImplTrait), Infer(TypeInfer), Macro(TypeMacro), Never(TypeNever), Paren(TypeParen), Path(TypePath), Ptr(TypePtr), Reference(TypeReference), Slice(TypeSlice), TraitObject(TypeTraitObject), Tuple(TypeTuple), Verbatim(TokenStream),
}
The possible types that a Rust value could have.

Syntax tree enum

This type is a syntax tree enum.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Array(TypeArray)

A fixed size array type: [T; n].



FnPtr(TypeFnPtr)

A function pointer type: fn(usize) -> bool.



Group(TypeGroup)

A type contained within invisible delimiters.



ImplTrait(TypeImplTrait)

An impl Bound1 + Bound2 + Bound3 type where Bound is a trait or a lifetime.



Infer(TypeInfer)

Indication that a type should be inferred by the compiler: _.



Macro(TypeMacro)

A macro in the type position.



Never(TypeNever)

The never type: !.



Paren(TypeParen)

A parenthesized type equivalent to the inner type.



Path(TypePath)

A path like core::slice::Iter, optionally qualified with a self-type as in <Vec<T> as SomeTrait>::Associated.



Ptr(TypePtr)

A raw pointer type: *const T or *mut T.



Reference(TypeReference)

A reference type: &'a T or &'a mut T.



Slice(TypeSlice)

A dynamically sized slice type: [T].



TraitObject(TypeTraitObject)

A trait object type dyn Bound1 + Bound2 + Bound3 where Bound is a trait or a lifetime.



Tuple(TypeTuple)

A tuple type: (A, B, C, String).



Verbatim(TokenStream)

Tokens in type position not interpreted by Syn.

Important: see Compatibility notes.

Implementations

Source

impl Type

pub fn without_plus(input: ParseStream<'_>) -> Result<Self>

In some positions, types may not contain the + character, to disambiguate them. For example in the expression 1 as T, T may not contain a + character.

This parser does not allow a +, while the default parser does.