WhereClausePlacement

Enum WhereClausePlacement 

pub enum WhereClausePlacement {
    Early,
    Late,
}

Variants



Early

type Ty<T> where T: 'static = T;

In associated types, this syntax is deprecated in favor of the late placement.

warning: where clause not allowed here
  --> src/main.rs
   |
   | impl Trait for Thing { type Ty<T> where T: 'static = T; }
   |                                   ^^^^^^^^^^^^^^^^
   = note: see issue #89122 <https://github.com/rust-lang/rust/issues/89122> for more information
   = note: `#[warn(deprecated_where_clause_location)]` on by default


Late

type Ty<T> = T where T: 'static;

In item-level type aliases, this syntax is unstable.

error: where clauses are not allowed after the type for type aliases
 --> src/main.rs
  |
  | type Ty<T> = T where T: 'static;
  |                ^^^^^^^^^^^^^^^^
  = note: see issue #112792 <https://github.com/rust-lang/rust/issues/112792> for more information
  = help: add `#![feature(lazy_type_alias)]` to the crate attributes to enable